@@ -35,10 +35,10 @@
 #'
 #' @param order Sort order, after which the last record shall be taken by
 #'              the `subject_keys` to determine Last Disease Assessment. Created
-#'              using `vars()`.
+#'              using `exprs()`.
 #'
 #'    *Permitted Values:* list of variables or `desc(<variable>)` function calls
-#'    created by `vars()`, e.g., `vars(ADT, desc(AVAL))`
+#'    created by `exprs()`, e.g., `exprs(ADT, desc(AVAL))`
 #'
 #' @param source_pd Date of first progressive disease (PD)
 #'
@@ -69,12 +69,12 @@
 #'
 #' @param subject_keys Columns to uniquely identify a subject
 #'
-#'   A list of symbols created using `vars()`.
+#'   A list of symbols created using `exprs()`.
 #'
 #' @param set_values_to Columns to set
 #'
-#'   A named list returned by `vars()` defining the columns to be set for the
-#'   new parameter, e.g. `vars(PARAMCD = "LSTAC", PARAM = "Last Disease
+#'   A named list returned by `exprs()` defining the columns to be set for the
+#'   new parameter, e.g. `exprs(PARAMCD = "LSTAC", PARAM = "Last Disease
 #'    Assessment Censored at First PD by Investigator")` is expected. The values
 #'    must be symbols, character strings, numeric values, or `NA`.
 #
@@ -91,7 +91,7 @@
 
 derive_param_lasta <- function(dataset,
                                filter_source,
-                               order = vars(ADT),
+                               order = exprs(ADT),
                                source_pd = NULL,
                                source_datasets = NULL,
                                subject_keys = get_admiral_option("subject_keys"),
