@@ -29,7 +29,7 @@ dyn_link <- function(text,
   return(link(text, url))
 }
 # Other variables
-admiral_homepage <- "https://pharmaverse.github.io/admiral"
+admiral_homepage <- "https://pharmaverse.github.io/admiral/cran-release"
 
 library(admiraldev)
 
@@ -53,7 +53,7 @@ knitr::kable(list_tte_source_objects(package = "admiralonco"))
 #  adsl_death_event <- event_source(
 #    dataset_name = "adsl",
 #    date = DTHDT,
-#    set_values_to = vars(
+#    set_values_to = exprs(
 #      EVNTDESC = "STUDY DEATH",
 #      SRCDOM = "ADSL",
 #      SRCVAR = "DTHDT"
@@ -65,15 +65,8 @@ adsl <- adsl %>%
   derive_vars_merged(
     dataset_add = adrs,
     filter_add = PARAMCD == "RSP" & AVALC == "Y" & ANL01FL == "Y",
-    by_vars = vars(STUDYID, USUBJID),
-    new_vars = vars(TEMP_RESPDT = ADT)
-  )
-
-adrs <- adrs %>%
-  derive_vars_merged(
-    dataset_add = adsl,
-    by_vars = vars(STUDYID, USUBJID),
-    new_vars = vars(TEMP_RESPDT)
+    by_vars = exprs(STUDYID, USUBJID),
+    new_vars = exprs(TEMP_RESPDT = ADT)
   )
 
 ## -----------------------------------------------------------------------------
@@ -83,7 +76,7 @@ adtte <- derive_param_tte(
   event_conditions = list(death_event),
   censor_conditions = list(lastalive_censor, rand_censor),
   source_datasets = list(adsl = adsl, adrs = adrs),
-  set_values_to = vars(PARAMCD = "OS", PARAM = "Overall Survival")
+  set_values_to = exprs(PARAMCD = "OS", PARAM = "Overall Survival")
 ) %>%
   derive_param_tte(
     dataset_adsl = adsl,
@@ -91,21 +84,21 @@ adtte <- derive_param_tte(
     event_conditions = list(pd_event, death_event),
     censor_conditions = list(lasta_censor, rand_censor),
     source_datasets = list(adsl = adsl, adrs = adrs),
-    set_values_to = vars(PARAMCD = "PFS", PARAM = "Progression Free Survival")
+    set_values_to = exprs(PARAMCD = "PFS", PARAM = "Progression Free Survival")
   ) %>%
   derive_param_tte(
-    dataset_adsl = adsl,
+    dataset_adsl = filter(adsl, !is.na(TEMP_RESPDT)),
     start_date = TEMP_RESPDT,
     event_conditions = list(pd_event, death_event),
     censor_conditions = list(lasta_censor),
-    source_datasets = list(adsl = filter(adsl, !is.na(TEMP_RESPDT)), adrs = filter(adrs, !is.na(TEMP_RESPDT))),
-    set_values_to = vars(PARAMCD = "RSD", PARAM = "Duration of Response")
+    source_datasets = list(adsl = adsl, adrs = adrs),
+    set_values_to = exprs(PARAMCD = "RSD", PARAM = "Duration of Response")
   )
 
 ## ---- echo=FALSE--------------------------------------------------------------
 dataset_vignette(
   adtte,
-  display_vars = vars(USUBJID, PARAMCD, PARAM, STARTDT, ADT, CNSR)
+  display_vars = exprs(USUBJID, PARAMCD, PARAM, STARTDT, ADT, CNSR)
 )
 
 ## ---- eval=FALSE--------------------------------------------------------------
@@ -113,7 +106,7 @@ dataset_vignette(
 #    dataset_name = "adsl",
 #    filter = PDDT < NACTDT | is.na(NACTDT),
 #    date = PDDT,
-#    set_values_to = vars(
+#    set_values_to = exprs(
 #      EVNTDESC = "Disease Progression prior to NACT",
 #      SRCDOM = "ADSL",
 #      SRCVAR = "PDDT"
@@ -124,7 +117,7 @@ dataset_vignette(
 #    dataset_name = "adsl",
 #    filter = DTHDT < NACTDT | is.na(NACTDT),
 #    date = DTHDT,
-#    set_values_to = vars(
+#    set_values_to = exprs(
 #      EVNTDESC = "Death prior to NACT",
 #      SRCDOM = "ADSL",
 #      SRCVAR = "DTHDT"
@@ -134,7 +127,7 @@ dataset_vignette(
 #  lasta_nact_censor <- censor_source(
 #    dataset_name = "adsl",
 #    date = LASTANDT,
-#    set_values_to = vars(
+#    set_values_to = exprs(
 #      EVNTDESC = "Last Tumor Assessment prior to NACT",
 #      CNSDTDSC = "Last Tumor Assessment prior to NACT",
 #      SRCDOM = "ADSL",
@@ -148,7 +141,7 @@ dataset_vignette(
 #    event_conditions = list(pd_nact_event, death_nact_event),
 #    censor_conditions = list(lasta_nact_censor, rand_censor),
 #    source_datasets = list(adsl = adsl),
-#    set_values_to = vars(PARAMCD = "PFSNACT", PARAM = "Progression Free Survival prior to NACT")
+#    set_values_to = exprs(PARAMCD = "PFSNACT", PARAM = "Progression Free Survival prior to NACT")
 #  )
 
 ## ----eval=TRUE----------------------------------------------------------------
@@ -176,8 +169,8 @@ dataset_vignette(
 ## ----eval=TRUE----------------------------------------------------------------
 adtte <- adtte %>%
   derive_var_obs_number(
-    by_vars = vars(STUDYID, USUBJID),
-    order = vars(PARAMCD),
+    by_vars = exprs(STUDYID, USUBJID),
+    order = exprs(PARAMCD),
     check_type = "error"
   )
 
@@ -188,13 +181,13 @@ dataset_vignette(adtte)
 adtte <- adtte %>%
   derive_vars_merged(
     dataset_add = adsl,
-    new_vars = vars(ARMCD, ARM, ACTARMCD, ACTARM, AGE, SEX),
-    by_vars = vars(STUDYID, USUBJID)
+    new_vars = exprs(ARMCD, ARM, ACTARMCD, ACTARM, AGE, SEX),
+    by_vars = exprs(STUDYID, USUBJID)
   )
 
 ## ---- echo=FALSE--------------------------------------------------------------
 dataset_vignette(
   adtte,
-  display_vars = vars(USUBJID, PARAMCD, CNSR, AVAL, ARMCD, AGE, SEX)
+  display_vars = exprs(USUBJID, PARAMCD, CNSR, AVAL, ARMCD, AGE, SEX)
 )
 
