@@ -1,7 +1,7 @@
 ## Test 1: An error is thrown if `derive_param_lasta()` is called ----
 test_that("deprecation Test 1: An error is thrown if `derive_param_lasta()` is called", {
   expect_error(
-    derive_param_lasta(admiralonco::admiral_adrs, set_values_to = vars(PARAMCD = "LSTA")),
+    derive_param_lasta(admiralonco::admiral_adrs, set_values_to = exprs(PARAMCD = "LSTA")),
     class = "lifecycle_error_deprecated"
   )
 })
